/**
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package us.levk.remote.drmaa.common.api;

import java.io.Serializable;
import java.util.List;
import java.util.UUID;

import org.ggf.drmaa.DrmaaException;


/**
 * This interface mimics the Session interface adding the instance id to all methods
 * 
 * @author levk
 *
 */
public interface RemoteSession extends Serializable {

  UUID init (String contact) throws DrmaaException;
  void exit (UUID session) throws DrmaaException;
  UUID createJobTemplate (UUID session) throws DrmaaException;
  void deleteJobTemplate (UUID session, UUID template) throws DrmaaException;
  String runJob (UUID session, UUID template) throws DrmaaException;
  List<?> runBulkJobs (UUID session, UUID template, int start, int end, int incr) throws DrmaaException;
  void control (UUID session, String jobId, int action) throws DrmaaException;
  void synchronize (UUID session, List<?> jobIds, long timeout, boolean dispose) throws DrmaaException;
  UUID wait (UUID session, String jobId, long timeout) throws DrmaaException;
  int getJobProgramStatus (UUID session, String jobId) throws DrmaaException;
}
